@@ -3,19 +3,17 @@
 use std::borrow::Cow;
 use std::error::Error as StdError;
 use std::fmt::{self, Debug};
-use std::io::{self, Write};
 use std::pin::Pin;
 use std::task::{self, Poll};
 
 use async_compression::tokio::bufread::{BrotliDecoder, DeflateDecoder, GzipDecoder};
-use bytes::{BufMut, Bytes, BytesMut};
+use bytes::{Bytes, BytesMut};
 use cookie::{Cookie, CookieJar};
 use encoding_rs::{Encoding, UTF_8};
 use futures_util::stream::{Stream, StreamExt, TryStreamExt};
 use http::version::Version;
 use mime::Mime;
 use serde::de::DeserializeOwned;
-use serde::Serialize;
 use tokio::io::{AsyncReadExt, BufReader};
 
 pub use http::response::Parts;
@@ -380,21 +378,6 @@ impl Response {
         self.http_error = Some(err);
     }
 
-    /// Render serializable data as json content. It will set ```content-type``` to ```application/json; charset=utf-8```.
-    pub fn render_json<T: Serialize>(&mut self, data: &T) {
-        let mut cache = Cache::with_capacity(128);
-        match serde_json::to_writer(&mut cache, data) {
-            Ok(_) => {
-                self.headers.insert(
-                    header::CONTENT_TYPE,
-                    HeaderValue::from_static("application/json; charset=utf-8"),
-                );
-                self.set_body(Some(Body::Bytes(cache.into_inner())));
-            }
-            Err(_) => self.set_http_error(InternalServerError().with_summary("error when serialize object to json")),
-        }
-    }
-
     /// Render text as html content. It will set ```content-type``` to ```text/html; charset=utf-8```.
     #[inline]
     pub fn render<P>(&mut self, piece: P)
@@ -495,29 +478,6 @@ impl fmt::Display for Response {
     }
 }
 
-pub(crate) struct Cache(BytesMut);
-
-impl Cache {
-    pub(crate) fn with_capacity(size: usize) -> Self {
-        Cache(BytesMut::with_capacity(size))
-    }
-
-    pub(crate) fn into_inner(self) -> BytesMut {
-        self.0
-    }
-}
-
-impl Write for Cache {
-    fn write(&mut self, buf: &[u8]) -> io::Result<usize> {
-        self.0.put(buf);
-        Ok(buf.len())
-    }
-
-    fn flush(&mut self) -> io::Result<()> {
-        Ok(())
-    }
-}
-
 #[cfg(test)]
 mod test {
     use bytes::BytesMut;
