@@ -14,11 +14,15 @@ use tokio::io::{AsyncRead, AsyncWrite, ReadBuf};
 use crate::addr::SocketAddr;
 use crate::transport::Transport;
 
+#[cfg(feature = "native-tls")]
+pub mod native_tls;
 #[cfg(feature = "rustls")]
 pub mod rustls;
 #[cfg(unix)]
 pub mod unix;
 
+#[cfg(feature = "native-tls")]
+pub use native_tls::NativeTlsListener;
 #[cfg(feature = "rustls")]
 pub use rustls::RustlsListener;
 #[cfg(unix)]
@@ -203,7 +207,7 @@ pub trait IntoAddrIncoming {
 impl IntoAddrIncoming for StdSocketAddr {
     #[inline]
     fn into_incoming(self) -> AddrIncoming {
-        let mut incoming = AddrIncoming::bind(&self.into()).unwrap();
+        let mut incoming = AddrIncoming::bind(&self).unwrap();
         incoming.set_nodelay(true);
         incoming
     }
